summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKarolin Seeger <kseeger@samba.org>2018-07-06 12:38:02 +0200
committerKarolin Seeger <kseeger@samba.org>2018-07-09 17:29:44 +0200
commit58403cb7053d8f0131e2780deb004ae094aa2d5c (patch)
treedbfdac1808e27d992ed010e08f422e790bd4d0e8
parent516448f203ea4fa721656fe7c92172ba9bdb44a9 (diff)
downloadsamba-58403cb7053d8f0131e2780deb004ae094aa2d5c.tar.gz
s3/notifyd.c: Rename CTDB_BROADCAST_VNNMAP to CTDB_BROADCAST_ACTIVE.
This fixes the build. Was introduced by a fix for BUG: https://bugzilla.samba.org/show_bug.cgi?id=13499. Signed-off-by: Karolin Seeger <kseeger@samba.org> Autobuild-User(v4-7-test): Karolin Seeger <kseeger@samba.org> Autobuild-Date(v4-7-test): Mon Jul 9 17:29:44 CEST 2018 on sn-devel-144
-rw-r--r--source3/smbd/notifyd/notifyd.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/smbd/notifyd/notifyd.c b/source3/smbd/notifyd/notifyd.c
index caf894e956e..693b924f2dc 100644
--- a/source3/smbd/notifyd/notifyd.c
+++ b/source3/smbd/notifyd/notifyd.c
@@ -81,7 +81,7 @@ struct notifyd_state {
* broadcasts its messaging_reclog to every other notifyd in
* the cluster. This is done by making ctdb send a message to
* srvid CTDB_SRVID_SAMBA_NOTIFY_PROXY with destination node
* number CTDB_BROADCAST_VNNMAP. Everybody in the cluster who
* had called register_with_ctdbd this srvid will receive the
* broadcasts.
*
@@ -998,7 +998,7 @@ static void notifyd_broadcast_reclog(struct ctdbd_connection *ctdbd_conn,
.iov_len = blob.length };
ret = ctdbd_messaging_send_iov(
- ctdbd_conn, CTDB_BROADCAST_VNNMAP,
+ ctdbd_conn, CTDB_BROADCAST_ACTIVE,
CTDB_SRVID_SAMBA_NOTIFY_PROXY, iov, ARRAY_SIZE(iov));
TALLOC_FREE(blob.data);
if (ret != 0) {
@@ -81,7 +81,7 @@ struct notifyd_state {
* the cluster. This is done by making ctdb send a message to
* srvid CTDB_SRVID_SAMBA_NOTIFY_PROXY with destination node
- * number CTDB_BROADCAST_VNNMAP. Everybody in the cluster who
+ * number CTDB_BROADCAST_ACTIVE. Everybody in the cluster who
* had called register_with_ctdbd this srvid will receive the
* broadcasts.